@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU Library General Public License
  * along with this library; if not, write to the Free Software Foundation,
- * Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307  USA.
+ * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
  *
  * THIS IS A PRIVATE HEADER FOR USE ONLY IN Gtk2 ITSELF.
  *
@@ -43,4 +43,14 @@ gboolean gtk2perl_tree_view_row_separator_func (GtkTreeModel *model,
 				                gpointer      data);
 #endif
 
+/* Implemented in GtkDialog.xs. */
+gint gtk2perl_dialog_response_id_from_sv (SV * sv);
+SV * gtk2perl_dialog_response_id_to_sv (gint response);
+void gtk2perl_dialog_response_marshal (GClosure * closure,
+                                       GValue * return_value,
+                                       guint n_param_values,
+                                       const GValue * param_values,
+                                       gpointer invocation_hint,
+                                       gpointer marshal_data);
+
 #endif /* _GTK2PERL_PRIVATE_H_ */
